==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/ar.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "عنوان غير معروف",
    "No result." : "لا توجد أي نتيجة",
    "Malformed JSON data." : "بيانات JSON غير مكونة بشكل صحيح",
    "Error" : "خطأ",
    "Weather status" : "حالة الطقس",
    "Weather status in your dashboard" : "حالة الطقس على لوحتك",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "حالة الطقس مدمجة في تطبيق لوحة المعلومات Dashboard في نكست كلاود. يمكن تحديد الموقع الجغرافي تلقائياً أو تحديده يدوياً. يتم بعد ذلك عرض توقعات الطقس لـ 6 ساعات قادمة. يمكن أيضًا دمج هذه الحالة في أماكن أخرى مثل تطبيق التقويم.",
    "Detect location" : "تحديد الموقع الجغرافي",
    "Set custom address" : "تعيين عنوان مخصص",
    "Favorites" : "المُفضّلة",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} سماءٌ صَحْوٌ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} clear sky" : "{temperature} {unit} سماءٌ صَحْوُ",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} طقسٌ مُغيّمٌ في وقت لاحقٍ من اليوم",
    "{temperature} {unit} cloudy" : "{temperature} {unit} غائم",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} ثلج و رعد في وقت لاحق من اليوم",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} ثلج و رعد",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} زخات ثلجية و رعد في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} زخات ثلجية و رعد",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} زخات ثلجية و رعد و شفق قطبي في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} زخات ثلجية و رعد وشفق قطبي",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} زخات ثلجية في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers" : "{temperature} {unit} زخات ثلجية",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} زخات ثلجية و شفق قطبي في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} زخات ثلجية و شفق قطبي",
    "{temperature} {unit} snow later today" : "{temperature} {unit} ثلج في وقت لاحق من اليوم",
    "{temperature} {unit} snow" : "{temperature} {unit} ثلج",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} طقسٌ مُعتَدِلٌ في وقت لاحق من اليوم",
    "{temperature} {unit} fair weather" : "{temperature} {unit} طقسٌ مُعتَدِلٌ",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} غائمٌ جزئيّاً في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} غائمٌ جزئيّاً ",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ضبابيٌّ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} foggy" : "{temperature} {unit} ضبابيٌّ",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} هُطولُ أمطارٍ خفيفةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} هُطولُ أمطارٍ خفيفةٍ  ",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} مُمطِرٌ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} rainfall" : "{temperature} {unit} مُمطِرٌ  ",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ  ",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} هُطولُ زخّاتٍ من المطر في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} هُطولُ زخّاتٍ من المطر  ",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} هُطولُ زخّاتٍ خفيفةٍ من المطر في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} هُطولُ زخّاتٍ خفيفةٍ من المطر  ",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ  ",
    "More weather for {adr}" : "المزيد عن الطقس في {adr}",
    "Loading weather" : "تحميل الطقس",
    "Set location for weather" : "تعيين المكان لمعرفة الطقس",
    "Remove from favorites" : "إزالة من المُفضّلة",
    "Add as favorite" : "إضافة إلى المُفضّلة",
    "You are not logged in." : "لم تقم بتسجيل الدخول.",
    "There was an error getting the weather status information." : "حدث خطأ أثناء محاولة الحصول على معلومات عن حالة الطقس",
    "No weather information found" : "لا توجد أيّ معلومات عن الطقس",
    "Location not found" : "الموقع الجغرافي غير موجود",
    "There was an error setting the location address." : "حدث خطأ أثناء تعيين عنوان الموقع الجغرافي.",
    "There was an error setting the location." : "حدث خطأ أثناء تعيين الموقع الجغرافي.",
    "There was an error saving the mode." : "حدث خطأ أثناء حفظ الوضعية mode.",
    "There was an error using personal address." : "حدث خطأ أثناء استعمال العنوان الشخصي.",
    "Unknown weather code" : "أحوال جوية غير محددة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/weather_status/l10n/ar.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "عنوان غير معروف",
    "No result." : "لا توجد أي نتيجة",
    "Malformed JSON data." : "بيانات JSON غير مكونة بشكل صحيح",
    "Error" : "خطأ",
    "Weather status" : "حالة الطقس",
    "Weather status in your dashboard" : "حالة الطقس على لوحتك",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "حالة الطقس مدمجة في تطبيق لوحة المعلومات Dashboard في نكست كلاود. يمكن تحديد الموقع الجغرافي تلقائياً أو تحديده يدوياً. يتم بعد ذلك عرض توقعات الطقس لـ 6 ساعات قادمة. يمكن أيضًا دمج هذه الحالة في أماكن أخرى مثل تطبيق التقويم.",
    "Detect location" : "تحديد الموقع الجغرافي",
    "Set custom address" : "تعيين عنوان مخصص",
    "Favorites" : "المُفضّلة",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} سماءٌ صَحْوٌ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} clear sky" : "{temperature} {unit} سماءٌ صَحْوُ",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} طقسٌ مُغيّمٌ في وقت لاحقٍ من اليوم",
    "{temperature} {unit} cloudy" : "{temperature} {unit} غائم",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} ثلج و رعد في وقت لاحق من اليوم",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} ثلج و رعد",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} زخات ثلجية و رعد في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} زخات ثلجية و رعد",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} زخات ثلجية و رعد و شفق قطبي في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} زخات ثلجية و رعد وشفق قطبي",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} زخات ثلجية في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers" : "{temperature} {unit} زخات ثلجية",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} زخات ثلجية و شفق قطبي في وقت لاحق من اليوم",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} زخات ثلجية و شفق قطبي",
    "{temperature} {unit} snow later today" : "{temperature} {unit} ثلج في وقت لاحق من اليوم",
    "{temperature} {unit} snow" : "{temperature} {unit} ثلج",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} طقسٌ مُعتَدِلٌ في وقت لاحق من اليوم",
    "{temperature} {unit} fair weather" : "{temperature} {unit} طقسٌ مُعتَدِلٌ",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} غائمٌ جزئيّاً في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} غائمٌ جزئيّاً ",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ضبابيٌّ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} foggy" : "{temperature} {unit} ضبابيٌّ",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} هُطولُ أمطارٍ خفيفةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} هُطولُ أمطارٍ خفيفةٍ  ",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} مُمطِرٌ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} rainfall" : "{temperature} {unit} مُمطِرٌ  ",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ  ",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} هُطولُ زخّاتٍ من المطر في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} هُطولُ زخّاتٍ من المطر  ",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} هُطولُ زخّاتٍ خفيفةٍ من المطر في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} هُطولُ زخّاتٍ خفيفةٍ من المطر  ",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ في وقتٍ لاحقٍ من اليوم",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} هُطولُ أمطارٍ غزيرةٍ  ",
    "More weather for {adr}" : "المزيد عن الطقس في {adr}",
    "Loading weather" : "تحميل الطقس",
    "Set location for weather" : "تعيين المكان لمعرفة الطقس",
    "Remove from favorites" : "إزالة من المُفضّلة",
    "Add as favorite" : "إضافة إلى المُفضّلة",
    "You are not logged in." : "لم تقم بتسجيل الدخول.",
    "There was an error getting the weather status information." : "حدث خطأ أثناء محاولة الحصول على معلومات عن حالة الطقس",
    "No weather information found" : "لا توجد أيّ معلومات عن الطقس",
    "Location not found" : "الموقع الجغرافي غير موجود",
    "There was an error setting the location address." : "حدث خطأ أثناء تعيين عنوان الموقع الجغرافي.",
    "There was an error setting the location." : "حدث خطأ أثناء تعيين الموقع الجغرافي.",
    "There was an error saving the mode." : "حدث خطأ أثناء حفظ الوضعية mode.",
    "There was an error using personal address." : "حدث خطأ أثناء استعمال العنوان الشخصي.",
    "Unknown weather code" : "أحوال جوية غير محددة",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "تمّ دمج حالة الطقس في تطبيق لوحة القيادة dashboard. يمكن تحديد الموقع الجغرافي للمستخدم تلقائيًا أو تحديده يدويًا. يتم بعد ذلك عرض توقعات الطفس في الـ 6 ساعات القادمة. يمكن أيضًا دمج حالة الطقس هذه في أماكن أخرى مثل تطبيق التقويم."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
